# Net operations

[![Maintainability](https://api.codeclimate.com/v1/badges/412ebe5da91a6036f1bc/maintainability)](https://codeclimate.com/github/modemfux/net_operations/maintainability) [![Test Coverage](https://api.codeclimate.com/v1/badges/412ebe5da91a6036f1bc/test_coverage)](https://codeclimate.com/github/modemfux/net_operations/test_coverage)

Little module for network operations with BRASes, routers etc.

## TODO

- Add functions to get basic information about Huawei BRASes (i.e. software, cards etc)
- Add examples of usage
